===========================================
History
===========================================

0.2.8 (2021-02-06)
------------------

* Removed StackingRegressor and CheckingClassifier.
* Added provided_models method.
* Added adjusted r-squared metric.
* Added cardinality check to split categorical columns into low and high cardinality features. 
* Added different transformation pipeline for low and high cardinality features.
* Included all number dtypes as inputs.
* Fixed dependencies.
* Improved documentation.

0.2.7 (2020-07-09)
------------------

* Removed catboost regressor and classifier

0.2.6 (2020-01-22)
------------------

* Added xgboost, lightgbm, catboost regressors and classifiers

0.2.5 (2020-01-20)
------------------

* Removed troublesome regressors from list of CLASSIFIERS

0.2.4 (2020-01-19)
------------------

* Removed troublesome regressors from list of REGRESSORS
* Added feature to input custom metric for evaluation
* Added feature to return predictions as dataframe
* Added model training time for each model

0.2.3 (2019-11-22)
------------------

* Removed TheilSenRegressor from list of REGRESSORS
* Removed GaussianProcessClassifier from list of CLASSIFIERS


0.2.2 (2019-11-18)
------------------

* Fixed automatic deployment issue.

0.2.1 (2019-11-18)
------------------

* Release of Regression feature.

0.2.0 (2019-11-17)
------------------

* Release of Classification feature.

0.1.0 (2019-11-16)
------------------

* First release on PyPI.

